@@ -31,4 +31,9 @@ def test_ptms_included():
     db = AsdDB(DIR_TEST_DATA + "/asd")
     protein = db.get('ASD02400000_12')
     assert len(protein.ptms) == 4
-    assert [ptm.position for ptm in protein.ptms] == [85, 2, 83, 112]
\ No newline at end of file
+    assert [ptm.position for ptm in protein.ptms] == [85, 2, 83, 112]
+    
+def test_pdbs_included_no_url():
+    db = AsdDB(DIR_TEST_DATA + "/asd")
+    protein = db.get('ASD17430000_1')
+    assert len(protein.pdbs) == 15
\ No newline at end of file
